@@ -62,6 +62,11 @@ findCheckerboardCorners <- function(image.file, nx, ny, corner.file=NULL, verify
 	}else if(sum(is_image) == length(image_input)){
 	}else{stop("'image.file' input is a mix of folders and image files. Only input of one type allowed.")}
 
+	# GIVE ERROR IF IMAGE HAS EXTENSION OTHER THAN JPG/JPEG
+	if(!is.matrix(image.file)){
+		if(!grepl(pattern='[.]jpg$|[.]jpeg$', x=image.file[1], ignore.case=TRUE)) stop("Checkerboard detection is currently only available for jpeg images.")
+	}
+
 	# IF ANY OF THE OUTPUT PATHS ARE DIRECTORIES, AUTOMATICALLY ASSIGN NAMES
 	if(!is.null(corner.file)){
 		is_text <- grepl('.txt$', corner.file)
@@ -126,7 +131,8 @@ findCheckerboardCorners <- function(image.file, nx, ny, corner.file=NULL, verify
 			success <- FALSE
 
 			# CHECK THAT IMAGE FILE EXISTS
-			if(print.progress) cat(paste0("Loading image ", image_num, " (", image_name, ")...\n"))
+			
+			if(print.progress) cat(paste0("Loading image ", image_num, " (", gsub('%20', ' ', image_name), ")...\n"))
 			if(!file.exists(image.file[image_row, image_col])){
 				if(print.progress) cat(paste0(image.file[image_row, image_col], " not found.\n"))
 				next
